@@ -1,122 +1,19 @@
 ##########################################################
 ###### PL Standard Errors - no parallel    ###############
 ##########################################################
-transf.thresholds.fix2.firstlast.jac <- function(rho, j, gamma_j, i){
-  recursive.theta <- function(i) {
-    if (i == 0) 0
-    else return ((exp(gamma_j[i]) + recursive.theta(i - 1))/(1 + exp(gamma_j[i])))
-  }
-    theta <- sapply(1:length(gamma_j), function(i)
-      recursive.theta(i))
-    theta[i]
-}
-
-
-transf.thresholds.fix2.first.jac <- function(rho,j,gamma_j,i){
-      c(0, cumsum(c(1 ,exp(gamma_j))))[i+2]
-}
-
-corr.jac.num.fct <- function(rho, nu, i){
-  # i is the ith correlation parameter
-  L <- diag(rho$ndim)
-  angles <- pi * exp(nu)/(1 + exp(nu))
-  L[lower.tri(L)] <- cos(angles)
-  S <-  matrix(0, nrow = rho$ndim - 1, ncol = rho$ndim - 1)
-  S[lower.tri(S,diag=T)] <- sin(angles)
-  S <- apply(cbind(1, rbind(0, S)), 1, cumprod)
-  L <- L * t(S)
-  sigma <- tcrossprod(L)
-  sigma[lower.tri(sigma)][i]
-}
 
 PL_se <- function(rho){
-  par <- rho$optpar
-  ## analytic 
+  ## analytic
   cat("Computing variability and hessian matrix analytically ... \n")
   derivs_for_se <- derivs_ana(rho)
   rho$H.inv <- solve(derivs_for_se$H)
-  rho$V <- rho$n/(rho$n - length(par)) * derivs_for_se$V  ## see maop code, correct for degrees of freedom
+  rho$V <- rho$n/(rho$n - NCOL(derivs_for_se$V)) * derivs_for_se$V  ## see maop code, correct for degrees of freedom
   rho$varGamma <- rho$H.inv %*% rho$V %*% rho$H.inv ## inverse godambe
   rho$seGamma <- sqrt(diag(rho$varGamma))
   rho$claic <- 2 * rho$objective + 2 * sum(diag(rho$V %*% rho$H.inv))
   rho$clbic <- 2 * rho$objective + log(rho$n) * sum(diag(rho$V %*% rho$H.inv))
   rho
 }
-  # # ## numeric  -- use for checks
-  # rho$transf.thresholds.jac <- switch(rho$threshold,
-  #                                     fix2firstlast = transf.thresholds.fix2.firstlast.jac,
-  #                                     fix2first = transf.thresholds.fix2.first.jac)
-
-  # gamma <- par[1:rho$npar.thetas]
-  # if (rho$threshold == "flexible") {
-  #   jac <- lapply((1:rho$ndim)[which(rho$npar.theta.opt > 0)], function(j){ #rho$npar.theta
-  #     emat <- diag(rho$ntheta[j])
-  #     if (ncol(emat) >= 2) {
-  #       emat[,1] <- 1
-  #       for (k in 2:ncol(emat))
-  #         emat[(k:nrow(emat)), k] <-
-  #           exp(gamma[(rho$first.ind.theta[j]) + seq_len(rho$ntheta[j]-1)])[k - 1]
-  #     }
-  #     emat
-  #     })
-  # } else {
-  #   if (rho$threshold == "fix1first") {
-  #     jac <- lapply((1:rho$ndim)[which(rho$npar.theta.opt > 0)], function(j){ #rho$npar.theta
-  #       emat <- diag(rho$ntheta[j])
-  #       if (ncol(emat) >= 2) {
-  #         emat[,1] <- 1
-  #         for (k in 2:ncol(emat))
-  #           emat[(k:nrow(emat)), k] <-
-  #             exp(gamma[(rho$first.ind.theta[j]) + seq_len(rho$npar.theta.opt[j])-1])[k - 1] #rho$npar.theta
-  #       }
-  #       emat[-1,-1]
-  #     })
-  #   } else {
-  #     jac <- lapply((1:rho$ndim)[which(rho$npar.theta.opt > 0)], function(j){ #rho$npar.theta
-  #       gamma_j <- gamma[rho$first.ind.theta[j] + seq_len(rho$npar.theta.opt[j]) - 1] #rho$npar.theta
-  #       t(sapply(1:length(gamma_j),
-  #                function(i) grad(function(x) rho$transf.thresholds.jac(rho, j, x, i), x=gamma_j)))
-  #     })
-  #   }
-  # }
-  # ## no transform for betas
-  # jac[sum(rho$npar.theta.opt > 0) + seq_len(rho$npar.betas)] <- 1 #rho$npar.theta
-  # ## jacobian for spherical transf
-  # nu <- par[rho$npar.thetas + rho$npar.betas + seq_len(rho$npar.cor * rho$ncor.levels)]
-  # if (rho$error.structure$type %in% c("corEqui", "corAR1")){
-  #   corr.jac <- list(diag(rho$npar.sigmas))
-  # } else {
-  #     corr.jac <- lapply(1:rho$ncor.levels, function(l) t(sapply(1:rho$npar.cor, function(i) grad(function(x) corr.jac.num.fct(rho, x, i),
-  #                                         x=nu[(l - 1) * rho$npar.cor + seq_len(rho$npar.cor)]))))
-  # }
-  # jac[sum(rho$npar.theta.opt > 0)  + rho$npar.betas + seq_len(rho$ncor.levels)] <- corr.jac #rho$npar.theta
-  # if (rho$error.structure$type %in% c("covGeneral")) jac[sum(rho$npar.theta.opt > 0)  + rho$npar.betas + rho$ncor.levels + seq_len(rho$npar.cor.sd * rho$ncor.levels)] <-
-  #   exp(par[rho$npar.thetas + rho$npar.betas + rho$npar.cor * rho$ncor.levels + seq_len(rho$npar.cor.sd * rho$ncor.levels)]) #rho$npar.theta
-  # J <- as.matrix(bdiag(jac))
-  # J.inv <- solve(J)
-
-  #   rho$transf.par_i <- switch(rho$error.structure$type,
-  #                              corGeneral = transf.par.cor_i,
-  #                              corEqui    = transf.par.cor_i,
-  #                              corAR1     = transf.par.cor_i,
-  #                              covGeneral = transf.par.cov_i)
-  #   cat("Computing variability matrix numerically ... \n")
-  #   Vi <- matrix(0, ncol = length(par), nrow = rho$n)
-  #   for (i in 1:rho$n) {
-  #     if (i %% 100 == 0)  cat('Computed gradient for', i, 'out of', rho$n,'subjects\n')
-  #     Vi[i, ] <- grad(function(par) neglogPL_comp_i(par, rho, i), par, method = "Richardson")
-  #   }
-  #   cat("\n")
-  #   rho$Vi <-  Vi %*% J.inv
-  #   rho$V <- crossprod(rho$Vi) # original variability matrix
-
-  #   cat("\nComputing Hessian numerically ... \n")
-  #   Ht <-  hessian(function(par) PLfun(par, rho), par,
-  #                  method = "Richardson",
-  #                  method.args=list(eps=1e-6)) # Fisher matrix H(Gamma transf)
-  #   rho$H.inv <-   J %*%  solve(Ht) %*% t(J)
-
-  # }
 
 deriv_biv_norm <- function(A, B, r){
   dnorm(A) * pnorm((B - r * A)/sqrt(1 - r^2))
@@ -139,23 +36,36 @@ deriv_corr_t <- function(A, B, r, df){
     (1 + (A^2 - 2 * r * A * B + B^2)/(df * (1 - r^2)))^(- df/2)
 }
 
-set_deriv_functions <- function(rho) {
-  rho$dfun <- switch(rho$link,
-                     probit = dnorm,
-                     logit  = function(q) dt(q, df = rho$df.t))
-  rho$deriv_biv_fun <- switch(rho$link,
-                              probit = deriv_biv_norm,
-                              logit  = function(A, B, r) deriv_biv_t(A, B, r, df = rho$df.t))
-  rho$deriv_corr_fun <- switch(rho$link,
-                               probit = deriv_corr_norm,
-                               logit  = function(A, B, r) deriv_corr_t(A, B, r, df = rho$df.t))
-  rho
+deriv_biv_t_copula <- function(A, B, r, df, inf.value){
+  newA <- qt(plogis(A), df = df)
+  newB <- qt(plogis(B), df = df)
+  newA[newA > inf.value] <- inf.value
+  newA[newA < - inf.value] <- - inf.value
+  newB[newB > inf.value] <- inf.value
+  newB[newB < -inf.value] <- - inf.value
+  mu_c <- r * newA
+  sigma_c <- sqrt((df + newA^2)/(df + 1) * (1 - r^2))
+  df_c <- df + 1
+  dlogis(A) * pt((newB - mu_c)/sigma_c, df = df_c)
 }
-deriv_corr_rect <- function(Ukl, Lkl, r, deriv_corr_fun) {
-  -  (deriv_corr_fun(A =   Ukl[, 1], B = Ukl[, 2], r) -
-      deriv_corr_fun(A = Ukl[, 1], B = Lkl[, 2], r) -
-      deriv_corr_fun(A = Lkl[, 1], B = Ukl[, 2], r) +
-      deriv_corr_fun(A = Lkl[, 1], B = Lkl[, 2], r))
+
+deriv_corr_t_copula <- function(A, B, r, df, inf.value){
+  ## add transformation
+  newA <- qt(plogis(A), df = df)
+  newB <- qt(plogis(B), df = df)
+  newA[newA > inf.value] <- inf.value
+  newA[newA < - inf.value] <- - inf.value
+  newB[newB > inf.value] <- inf.value
+  newB[newB < - inf.value] <- - inf.value
+  1/(2 * pi * sqrt(1 - r^2)) *
+    (1 + (newA^2 - 2 * r * newA * newB + newB^2)/(df * (1 - r^2)))^(- df/2)
+}
+
+deriv_corr_rect <- function(U_kl, L_kl, r, deriv_corr_fun) {
+  -  (deriv_corr_fun(A = U_kl[, 1], B = U_kl[, 2], r) -
+      deriv_corr_fun(A = U_kl[, 1], B = L_kl[, 2], r) -
+      deriv_corr_fun(A = L_kl[, 1], B = U_kl[, 2], r) +
+      deriv_corr_fun(A = L_kl[, 1], B = L_kl[, 2], r))
 }
 
 deriv_theta_rect <- function(k, l,
@@ -189,14 +99,49 @@ deriv_stddev_rect <- function(k, l, U, L, r, deriv_biv_fun){
     (UU * U[, k] - UL * U[, k] - LU  * L[, k] + LL * L[, k])
 }
 
+set_deriv_functions <- function(rho) {
+  rho$pfun <- switch(rho$link$name,
+                     mvprobit = pnorm,
+                     mvlogit  = plogis) # function for univariate probabilities
+  rho$bivpfun <- switch(rho$link$name,
+                     mvprobit = function(U, L, r) rectbiv.norm.prob(U, L, r),
+                     mvlogit  = function(U, L, r) {
+                       U <- qt(plogis(U), df = rho$link$df)
+                       L <- qt(plogis(L), df = rho$link$df)
+                       U[U > rho$inf.value] <- rho$inf.value
+                       L[L < -rho$inf.value] <- - rho$inf.value
+                       sapply(seq_len(nrow(U)), function(i)
+                          biv.nt.prob2(df = rho$link$df,
+                                       lower = L[i, ],
+                                       upper = U[i, ],
+                                       r     = r[i]))}) # function for bivariate probabilities
+
+  rho$dfun <- switch(rho$link$name,
+                     mvprobit = dnorm,
+                     mvlogit  = dlogis) # univariate density
+  rho$deriv_biv_fun <- switch(rho$link$name,
+                              mvprobit = deriv_biv_norm,
+                              mvlogit  = function(A, B, r) deriv_biv_t_copula(A, B, r,
+                                                                              df = rho$link$df,
+                                                                              inf.value = rho$inf.value))
+  rho$deriv_corr_fun <- switch(rho$link$name,
+                               mvprobit = deriv_corr_norm,
+                               mvlogit  = function(A, B, r) deriv_corr_t_copula(A, B, r,
+                                                                                df = rho$link$df,
+                                                                                inf.value = rho$inf.value))
+  rho
+}
+
 derivs_ana <- function(rho){
   ## function for analytic gradient and hessian
   rho <- set_deriv_functions(rho)
   par <- rho$optpar
+
   tmp <- rho$transf.par(par, rho)
-
-  U <- tmp$U; L <- tmp$L; sigmas <- tmp$sigmas;
-
+  U <- tmp$U
+  L <- tmp$L
+  sigmas <- tmp$sigmas;
+  ## prepare contrast matrices for threshold parameters
   rho$B2 <- lapply(1:rho$ndim, function(j)
     1 * (col(matrix(0, rho$n, rho$ntheta[j] + 1)) ==
            c(unclass(rho$y[, j]))))
@@ -215,6 +160,7 @@ derivs_ana <- function(rho){
     std.dev <- rep(list(rep(1, rho$ndim)), rho$ncor.levels)
   }
   std.dev.mat <- do.call("rbind",  std.dev[lev])
+
   npar.beta.opt <- apply(rho$ind.coef, 1, function(x) sum(!is.na(x)))
   pick.col.beta <- lapply(seq_len(nrow(rho$ind.coef)), function(i)
     which(!is.na(rho$ind.coef[i, ])))
@@ -225,7 +171,6 @@ derivs_ana <- function(rho){
       k[k != 0]
   })))
 
-
   ## First take care of the univariate case (q_i = 1)
   if (length(contrast_uni) > 0) {
    h_list <- lapply(contrast_uni, function(k) {
@@ -241,16 +186,19 @@ derivs_ana <- function(rho){
                          fix2first     = seq_len(rho$ntheta[k])[-c(1,2)],
                          fix2firstlast = seq_len(rho$ntheta[k] - 1)[-1])
     if (length(pick.col.theta) != 0) {
-      colposk <- rho$first.ind.theta[k] + seq_len(rho$npar.theta[k]) - 1
-      dtheta[indk, colposk] <- -  1/rho$sd.y * 1/std.dev.mat[indk, k] *
+      # first indices of thresholds in parameter vector for each rater
+      first.ind.theta <- sapply(rho$ind.thresholds, "[", 1)
+      colposk <- first.ind.theta[k] + seq_len(rho$npar.theta[k]) - 1
+      dtheta[indk, colposk] <- -  1/std.dev.mat[indk, k] *
          (rho$dfun(U[indk, k]) * rho$B1[[k]][indk, pick.col.theta] -
           rho$dfun(L[indk, k]) * rho$B2[[k]][indk, pick.col.theta])
     } else dtheta <- NULL
 
     # dbeta
     dbeta <- matrix(0, nrow = rho$n, ncol = rho$npar.betas)
-    colposk <- (rho$first.ind.beta[k] -  rho$npar.thetas) + seq_len(npar.beta.opt[k]) - 1
-    dbeta[indk, colposk] <-  1/rho$sd.y * 1/std.dev.mat[indk, k] *
+    first.ind.beta <- apply(getInd.coef(rho$coef.constraints, rho$coef.values), 1, min, na.rm  = T)
+    colposk <- first.ind.beta[k]  + seq_len(npar.beta.opt[k]) - 1
+    dbeta[indk, colposk] <-  1/std.dev.mat[indk, k] *
       (rho$dfun(U[indk, k]) - rho$dfun(L[indk, k])) * rho$x[[k]][indk, pick.col.beta[[k]]]
     # dcorr -- no correlation for univ case
     dcorr <- matrix(0, nrow = rho$n, ncol = rho$npar.cor * rho$ncor.levels)
@@ -259,12 +207,12 @@ derivs_ana <- function(rho){
     if (rho$error.structure$type == "covGeneral"){
       dstddev <- matrix(0, nrow = rho$n, ncol = rho$npar.cor.sd * rho$ncor.levels)
       arr.ind.k <- cbind(which(indk), (lev - 1) * rho$npar.cor.sd + k)
-      dstddev[arr.ind.k] <-  1/rho$sd.y * 1/std.dev.mat[indk, k] *
-             (rho$dfun(U[indk, k]) * U[indk, k] - 
+      dstddev[arr.ind.k] <-  1/std.dev.mat[indk, k] *
+             (rho$dfun(U[indk, k]) * U[indk, k] -
               rho$dfun(L[indk, k]) * L[indk, k])
     } else dstddev <- NULL
-  
-    rho$weights * 1/pr * cbind(dtheta, dbeta, dcorr, dstddev) 
+
+    rho$weights * 1/pr * cbind(dtheta, dbeta, dcorr, dstddev)
   })
   } else {
     h_list <- NULL
@@ -293,8 +241,8 @@ derivs_ana <- function(rho){
 
     pr <- rep(1, rho$n)
     pr[indkl] <- rho$bivpfun(U = U[indkl, comb, drop = F],
-                       L = L[indkl, comb, drop = F],
-                       r = r)
+                             L = L[indkl, comb, drop = F],
+                             r = r)
     pr[pr < .Machine$double.eps] <- .Machine$double.eps
 
    ## vector h_kl will contain the gradient for all d log p_{kl}/d pars
@@ -316,7 +264,7 @@ derivs_ana <- function(rho){
                       Umatk = rho$B1[[k]][indkl, pick.col.theta, drop = F],
                       Lmatk = rho$B2[[k]][indkl, pick.col.theta, drop = F],
                       deriv_biv_fun = rho$deriv_biv_fun,
-                      sdfack = rho$sd.y * std.dev.mat[indkl, k]) )
+                      sdfack =  std.dev.mat[indkl, k]) )
     } else {
      return(NULL)
     }
@@ -343,7 +291,7 @@ derivs_ana <- function(rho){
    dbeta <- matrix(0, ncol = rho$npar.betas,
                             nrow = rho$n)
 
-   ## for which covariates are there betas to be estimated 
+   ## for which covariates are there betas to be estimated
    active_p <- which(apply(rho$ind.coef, 2, function(x) !all(is.na(x))))
 
    rho$deriv_beta_rect_klp <- function(k, l, p) {
@@ -351,10 +299,10 @@ derivs_ana <- function(rho){
                       U = U[indkl, ], L = L[indkl, ], r = r,
                       Xmatk = rho$x[[k]][indkl, p],
                       deriv_biv_fun = rho$deriv_biv_fun,
-                      sdfack = rho$sd.y * std.dev.mat[indkl, k])
+                      sdfack = std.dev.mat[indkl, k])
    }
    for (p in active_p) {
-     dbeta[indkl, unique(rho$ind.coef[!is.na(rho$ind.coef[, p]), p])] <- 
+     dbeta[indkl, unique(rho$ind.coef[!is.na(rho$ind.coef[, p]), p])] <-
      do.call("cbind", lapply(unique(rho$coef.constraints[!is.na(rho$coef.constraints[,p]),p]), function(j){
      indjj <- (1:rho$ndim)[rho$coef.constraints[, p] == j]
      indj <- indjj[indjj %in% comb]
@@ -375,24 +323,29 @@ derivs_ana <- function(rho){
   if (rho$error.structure$type == "corAR1") {
     rpowinvlag <- r^(1/abs(comb[1] - comb[2]))
     dLdr <- abs(comb[1] - comb[2]) * rpowinvlag^(abs(comb[1] - comb[2]) - 1) *
-                  deriv_corr_rect(U[indkl, comb, drop = F],
-                            L[indkl, comb, drop = F], r = r,
-                            deriv_corr_fun = rho$deriv_corr_fun)
+                  deriv_corr_rect(U_kl = U[indkl, comb, drop = F],
+                                  L_kl = L[indkl, comb, drop = F],
+                                  r = r,
+                                  deriv_corr_fun = rho$deriv_corr_fun)
 
     xbeta <- 0.5 * (log(1 + rpowinvlag) - log(1 - rpowinvlag))
     dcorr[indkl, ] <- dLdr * exp(2 * xbeta)/(exp(2 * xbeta) + 1)^2  * 4 * rho$error.structure$x[indkl, ]
   } else {
     if (rho$error.structure$type == "corEqui") {
-      dLdr <- deriv_corr_rect(Ukl=U[indkl, comb], Lkl=L[indkl, comb], r = r, deriv_corr_fun = rho$deriv_corr_fun)
+      dLdr <- deriv_corr_rect(U_kl = U[indkl, comb],
+                              L_kl = L[indkl, comb],
+                              r = r,
+                              deriv_corr_fun = rho$deriv_corr_fun)
       xbeta <- 0.5 * (log(1 + r) - log(1 - r))
       dcorr[indkl, ] <- dLdr * exp(2 * xbeta)/(exp(2 * xbeta) + 1)^2  * 4 * rho$error.structure$x[indkl, ]
     } else {
       poslev <- which(sapply(combn(rho$ndim, 2, simplify=F), function(x) all(x==comb)))
 
       arr.ind <- cbind(which(indkl), (lev[indkl]-1) * rho$npar.cor + poslev)
-      dcorr[arr.ind] <- deriv_corr_rect(Ukl = U[indkl, comb, drop = F],
-                                                Lkl = L[indkl, comb, drop = F],
-                                                r = r, deriv_corr_fun = rho$deriv_corr_fun)
+      dcorr[arr.ind] <- deriv_corr_rect(U_kl = U[indkl, comb, drop = F],
+                                        L_kl = L[indkl, comb, drop = F],
+                                        r = r,
+                                        deriv_corr_fun = rho$deriv_corr_fun)
     }
   }
   ## dstddev
@@ -402,13 +355,13 @@ derivs_ana <- function(rho){
     poslevl <- (lev[indkl] - 1) * rho$npar.cor.sd + l
     arr.ind.k <- cbind(which(indkl), poslevk)
     arr.ind.l <- cbind(which(indkl), poslevl)
-    dstddev[arr.ind.k] <- 1/rho$sd.y * 1/std.dev.mat[indkl, k] *
+    dstddev[arr.ind.k] <- 1/std.dev.mat[indkl, k] *
       deriv_stddev_rect(k, l,
                          U = U[indkl, , drop = F],
                          L = L[indkl, , drop = F], r,
                          deriv_biv_fun = rho$deriv_biv_fun)
 
-    dstddev[arr.ind.l] <- 1/rho$sd.y * 1/std.dev.mat[indkl, l] *
+    dstddev[arr.ind.l] <-  1/std.dev.mat[indkl, l] *
        deriv_stddev_rect(l, k,
                          U = U[indkl, , drop = F],
                          L = L[indkl, , drop = F], r,
@@ -417,86 +370,11 @@ derivs_ana <- function(rho){
   } else dstddev <- NULL
   h_list[[it]] <- rho$weights * 1/pr * cbind(dtheta, dbeta, dcorr, dstddev)
   }
+  ## matrix containing the gradients for each subject
   Vi <- Reduce("+", h_list)
+  ## variability matrix
   V <- crossprod(Vi)
-
+  ## Hessian matrix
   H <- Reduce("+", lapply(h_list, crossprod))
-
-  list(Vi = Vi, V = V, H = H)
+  list(V = V, H = H)
 }
-
-#############################################################
-###### neg loglikelihood component for each subject i #######
-######                 for numeric gradient           #######
-#############################################################
-transf.par.cor_i <- function(par, rho, i) {
-  sigmas <- rho$transf.sigmas(par[rho$npar.thetas + rho$npar.betas + seq_len(rho$npar.sigmas)],rho)
-  #transform thresholds due to monotonicity
-  theta <- rho$transf.thresholds(par[seq_len(rho$npar.thetas)], rho)
-  par_beta <- par[rho$npar.thetas + seq(rho$npar.betas)]
-  beta <- sapply(1:ncol(rho$coef.constraints), function(j){
-    sapply(1:nrow(rho$coef.constraints), function(i,j)
-      ifelse(is.na(rho$ind.coef[i,j]), rho$coef.values[i,j], par_beta[rho$ind.coef[i, j]]), j)
-  })
-  pred.fixed <- sapply(1:rho$ndim, function(j) rho$x[[j]][i, ] %*% beta[j, ])
-  theta.lower <- sapply(1:rho$ndim, function(j) c(-rho$inf.value, theta[[j]])[rho$y[i, j]])
-  theta.upper <- sapply(1:rho$ndim, function(j) c(theta[[j]], rho$inf.value)[rho$y[i, j]])
-  pred.lower <- (theta.lower - pred.fixed)/rho$sd.y
-  pred.upper <- (theta.upper - pred.fixed)/rho$sd.y
-  list(U = pred.upper, L = pred.lower,
-       sigmas = sigmas)
-}
-##############
-transf.par.cov_i <- function(par, rho, i) {
-  exp.par.sd <- exp(par[rho$npar.thetas + rho$npar.betas + rho$npar.cor * rho$ncor.levels + seq_len(rho$npar.cor.sd *  rho$ncor.levels)])
-  sigmas <- rho$transf.sigmas(par[rho$npar.thetas + rho$npar.betas + seq_len(rho$npar.sigmas)],rho, exp.par.sd)
-  exp.par.sd <- lapply(1:rho$ncor.levels, function(l) exp.par.sd[ (l-1) * rho$npar.cor.sd + seq_len(rho$npar.cor.sd) ])
-  lev <- match(rho$error.structure$x[i], rho$error.structure$levels)
-  #transform thresholds due to monotonicity
-  theta <- rho$transf.thresholds(par[seq_len(rho$npar.thetas)], rho)
-  par_beta <- par[rho$npar.thetas + seq(rho$npar.betas)]
-  beta <- sapply(1:ncol(rho$coef.constraints), function(j){
-    sapply(1:nrow(rho$coef.constraints), function(i,j)
-      ifelse(is.na(rho$ind.coef[i,j]), rho$coef.values[i,j], par_beta[rho$ind.coef[i, j]]), j)
-  })
-  pred.fixed <- sapply(1:rho$ndim, function(j) rho$x[[j]][i, ] %*% beta[j, ])
-  theta.lower <- sapply(1:rho$ndim, function(j) c(-rho$inf.value, theta[[j]])[rho$y[i, j]])
-  theta.upper <- sapply(1:rho$ndim, function(j) c(theta[[j]], rho$inf.value)[rho$y[i, j]])
-  pred.lower <-  ((theta.lower - pred.fixed)/rho$sd.y)/exp.par.sd[[lev]]
-  pred.upper <-  ((theta.upper - pred.fixed)/rho$sd.y)/exp.par.sd[[lev]]
-  sigmas <- lapply(sigmas, cov2cor)
-  list(U = pred.upper, L = pred.lower,
-       sigmas = sigmas)
-}
-##############
-neglogPL_comp_i <- function(par, rho, i) {
-  # transform parameters and get upper and lower bounds
-  tmp <- rho$transf.par_i(par, rho, i)
-  U <- tmp$U; L <- tmp$L; sigmas <- tmp$sigmas
-  q <- which(!is.na(rho$y[i, ]))
-  if (length(q) == 0) logPLi <- 0
-  else {
-  if (length(q) == 1){
-    pr <- rho$pfun(U[q]) - rho$pfun(L[q])
-    logPLi <- rho$weights[i] * log(max(pr, .Machine$double.eps))
-  } else {
-    combis <- combn(q, 2)
-    combis <- combis[,which((combis[2,] - combis[1,])  <= rho$PL.lag), drop = FALSE]
-    logPLi <- 0
-    dim(U) <- dim(L) <- c(1, length(U))
-    for (h in seq_len(ncol(combis))) {
-      if(rho$error.structure$type %in% c("corGeneral", "covGeneral")){
-        lev <- match(rho$error.structure$x[i], rho$error.structure$levels)
-        r <- sigmas[[lev]][combis[1, h], combis[2, h]]
-        } else if(rho$error.structure$type %in% c("corAR1")){
-           r <- sigmas[[i]][combis[1, h], combis[2, h]]
-        } else r <- sigmas[i]
-      pr <- rho$bivpfun(U = U[,combis[, h], drop = F],
-                        L = L[,combis[, h], drop = F],
-                        r)
-      logPLi <- logPLi + rho$weights[i] * log(max(pr, .Machine$double.eps))
-    }
-  }
-}
-  -logPLi
-}
\ No newline at end of file
