@@ -1,175 +1,190 @@
 ### R code from vignette source 'vignette_mvord.Rnw'
 
 ###################################################
-### code chunk number 1: vignette_mvord.Rnw:79-85
+### code chunk number 1: vignette_mvord.Rnw:77-78
 ###################################################
-options(width=65, prompt = "R> ", continue = "+  ", useFancyQuotes = FALSE)
+options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
+
+
+###################################################
+### code chunk number 2: vignette_mvord.Rnw:82-87
+###################################################
+library("mvord")
+data("data_cr_panel")
+data("data_cr_mvord")
+data("data_cr_mvord2")
 cache <- TRUE
-library(mvord)
-data(data_cr_panel)
-data(data_cr_multord)
-data(data_cr_multord2)
 
 
 ###################################################
-### code chunk number 2: vignette_mvord.Rnw:561-578 (eval = FALSE)
+### code chunk number 3: vignette_mvord.Rnw:675-693 (eval = FALSE)
 ###################################################
-## multord(formula,
-##         error.structure = corGeneral(~1),
-##         link = c("probit", "logit"),
-##         data,
-##         index = NULL,
-##         response.names = NULL,
-##         response.levels = NULL,
-##         coef.constraints = NULL,
-##         coef.values = NULL,
-##         threshold.constraints = NULL,
-##         threshold.values = NULL,
-##         weights = NULL,
-##         se = TRUE,
-##         start.values = NULL,
-##         solver = "BFGS",
-##         control = list(maxit=200000, trace = 1, kkt = FALSE)
+## mvord(formula,
+##       data,
+##       error.structure = corGeneral(~ 1),
+##       link = mvprobit(),
+##       index = NULL,
+##       response.names = NULL,
+##       response.levels = NULL,
+##       threshold.constraints = NULL,
+##       threshold.values = NULL,
+##       coef.constraints = NULL,
+##       coef.values = NULL,
+##       weights = NULL,
+##       se = TRUE,
+##       start.values = NULL,
+##       solver = "BFGS",
+##       PL.lag = NULL,
+##       control = list(maxit=200000, trace = 1, kkt = FALSE)
 ## )
 
 
 ###################################################
-### code chunk number 3: vignette_mvord.Rnw:589-591
+### code chunk number 4: vignette_mvord.Rnw:709-711
 ###################################################
-head(data_cr_multord, n = 3)
-str(data_cr_multord, vec.len = 3)
-
-
-###################################################
-### code chunk number 4: vignette_mvord.Rnw:610-612
-###################################################
-index <- c("firm_id", "rater_id")
+index <- c("subject_index", "multiple_measurement_index")
 index
 
 
 ###################################################
-### code chunk number 5: vignette_mvord.Rnw:623-625
+### code chunk number 5: vignette_mvord.Rnw:724-726
 ###################################################
-response.names <- c("R1", "R2", "R3", "R4")
+response.names <- c("Y1", "Y2", "Y3", "Y4")
 response.names
 
 
 ###################################################
-### code chunk number 6: vignette_mvord.Rnw:634-640
+### code chunk number 6: vignette_mvord.Rnw:729-734
 ###################################################
-response.levels <-  list(rev(LETTERS[1:6]),
-                         rev(LETTERS[1:6]),
-                         rev(LETTERS[7:13]),
-                         rev(LETTERS[14:15]))
-names(response.levels) <- response.names
+response.levels <-  list(Y1 = rev(LETTERS[1:6]),
+                         Y2 = rev(LETTERS[1:6]),
+                         Y3 = rev(LETTERS[7:13]),
+                         Y4 = c("O", "N"))
 response.levels
 
 
 ###################################################
-### code chunk number 7: vignette_mvord.Rnw:677-678
+### code chunk number 7: vignette_mvord.Rnw:746-747
 ###################################################
-formula <- rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR
+formula = Y ~ 0 + X1 + ... + Xp
 
 
 ###################################################
-### code chunk number 8: vignette_mvord.Rnw:684-685
+### code chunk number 8: vignette_mvord.Rnw:753-754
 ###################################################
-formula <- rating ~ 1 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR
+formula = Y ~ 1 + X1 + ... + Xp
 
 
 ###################################################
-### code chunk number 9: vignette_mvord.Rnw:688-689
+### code chunk number 9: vignette_mvord.Rnw:757-758
 ###################################################
-formula <- rating ~ ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR
+formula = Y ~ X1 + ... + Xp
 
 
 ###################################################
-### code chunk number 10: vignette_mvord.Rnw:708-709
+### code chunk number 10: vignette_mvord.Rnw:768-769
 ###################################################
-error.structure <- corGeneral(~ 1)
+link = mvprobit()
 
 
 ###################################################
-### code chunk number 11: vignette_mvord.Rnw:712-713
+### code chunk number 11: vignette_mvord.Rnw:774-775
 ###################################################
-error.structure = corGeneral(~ f)
+link = mvlogit(df = 8L)
 
 
 ###################################################
-### code chunk number 12: vignette_mvord.Rnw:719-720
+### code chunk number 12: vignette_mvord.Rnw:806-807
 ###################################################
-error.structure <- corEqui(~ S1 + ... + Sm)
+error.structure = corGeneral(~ 1)
 
 
 ###################################################
-### code chunk number 13: vignette_mvord.Rnw:726-727
+### code chunk number 13: vignette_mvord.Rnw:811-812
+###################################################
+error.structure = corEqui(~ 1)
+
+
+###################################################
+### code chunk number 14: vignette_mvord.Rnw:816-817
 ###################################################
 error.structure = corAR1(~ 1)
 
 
 ###################################################
-### code chunk number 14: vignette_mvord.Rnw:730-731
-###################################################
-error.structure = corAR1(~ S1 + ... + Sm)
-
-
-###################################################
-### code chunk number 15: vignette_mvord.Rnw:738-739
+### code chunk number 15: vignette_mvord.Rnw:829-830
 ###################################################
 error.structure = covGeneral(~ 1)
 
 
 ###################################################
-### code chunk number 16: vignette_mvord.Rnw:742-743
+### code chunk number 16: vignette_mvord.Rnw:844-845
+###################################################
+error.structure = corGeneral(~ f)
+
+
+###################################################
+### code chunk number 17: vignette_mvord.Rnw:849-850
+###################################################
+error.structure = corEqui(~ S1 + ... + Sm)
+
+
+###################################################
+### code chunk number 18: vignette_mvord.Rnw:854-855
+###################################################
+error.structure =  corAR1(~ S1 + ... + Sm)
+
+
+###################################################
+### code chunk number 19: vignette_mvord.Rnw:865-866
 ###################################################
 error.structure = covGeneral(~ f)
 
 
 ###################################################
-### code chunk number 17: vignette_mvord.Rnw:800-803
+### code chunk number 20: vignette_mvord.Rnw:893-896
 ###################################################
 threshold.constraints <- c(1, 1, 2, 3)
-names(threshold.constraints) <- response.names
+names(threshold.constraints) <- paste0("Y", 1:4)
 threshold.constraints
 
 
 ###################################################
-### code chunk number 18: vignette_mvord.Rnw:880-886
+### code chunk number 21: vignette_mvord.Rnw:970-976
 ###################################################
 threshold.values <- list(c(-4, NA, NA, NA, NA, NA),
                          c(-4, NA, NA, NA, NA, NA),
                          c(-5, NA, NA, NA, NA, NA, NA),
                          c(0))
-names(threshold.values) <- response.names
+names(threshold.values) <- paste0("Y", 1:4)
 threshold.values
 
 
 ###################################################
-### code chunk number 19: vignette_mvord.Rnw:944-947
+### code chunk number 22: vignette_mvord.Rnw:997-1000
 ###################################################
 coef.constraints <- c(1, 1, 2, 3)
-names(coef.constraints) <- response.names
+names(coef.constraints) <- paste0("Y", 1:4)
 coef.constraints
 
 
 ###################################################
-### code chunk number 20: vignette_mvord.Rnw:974-985
+### code chunk number 23: vignette_mvord.Rnw:1019-1029
 ###################################################
-coef.constraints = cbind(c(1, NA, 1, NA),
-                         c(NA, NA, NA, 1),
-                         c(1, 1, 1, NA),
-                         c(1, 2, 3, 4),
-                         c(1, 1, 1, 4),
-                         c(1, 2, 3, 4),
-                         c(NA, NA, NA, 1))
-rownames(coef.constraints) <- response.names
-colnames(coef.constraints) <- c("ICR", "LR", "LEV1", "LEV2", "PR",
-                                "lRSIZE", "lSYSR")
+coef.constraints <- cbind(c(1, 2, 3, 4),
+                          c(1, 1, 1, 2),
+                          c(NA, NA, NA, 1),
+                          c(1, 1, 1, NA),
+                          c(NA, NA, NA, NA),
+                          c(1, 2, 3, 4),
+                          c(1, 2, 3, 4))
+rownames(coef.constraints) <- paste0("Y", 1:4)
+colnames(coef.constraints) <- paste0("X", 1:7)
 coef.constraints
 
 
 ###################################################
-### code chunk number 21: vignette_mvord.Rnw:1027-1038
+### code chunk number 24: vignette_mvord.Rnw:1049-1059
 ###################################################
 coef.values <- cbind(c(NA, NA, NA, NA),
                      c(NA, NA, NA, NA),
@@ -178,121 +193,108 @@ coef.values <- cbind(c(NA, NA, NA, NA),
                      c(2, 2, 2, 2),
                      c(NA, NA, NA, NA),
                      c(NA, NA, NA, NA))
-rownames(coef.values) <- response.names
-colnames(coef.values) <- c("ICR", "LR", "LEV1", "LEV2", "PR",
-                           "lRSIZE", "lSYSR")
+rownames(coef.values) <- paste0("Y", 1:4)
+colnames(coef.values) <- paste0("X", 1:7)
 coef.values
 
 
 ###################################################
-### code chunk number 22: vignette_mvord.Rnw:1048-1050
+### code chunk number 25: vignette_mvord.Rnw:1076-1077
 ###################################################
-formula <- rating ~ 0 + ICR : LR + LEV1 + LEV2 + PR + lRSIZE * lSYSR
-colnames(model.matrix(formula, data = data_cr_multord))
+data_x <- cbind.data.frame("Y" = "A", X1 = 1, X2 = 2, X3 = 3, X4 =4, X5 = 5, X6 = 6, X7 = 7)
 
 
 ###################################################
-### code chunk number 23: vignette_mvord.Rnw:1080-1085 (eval = FALSE)
+### code chunk number 26: vignette_mvord.Rnw:1079-1081
+###################################################
+formula <- Y ~ 0 + X1 : X2 + X3 + X4 + X5 + X6 * X7
+colnames(model.matrix(formula, data = data_x))
+
+
+###################################################
+### code chunk number 27: vignette_mvord.Rnw:1102-1107 (eval = FALSE)
 ###################################################
 ## solver = function(starting.values, objFun, control){
 ##   optRes <- solver.function(...)
-##   list(optpar = , optRes$optpar, # a vector of length equal to number of parameters to optimize
-##        objvalue = optRes$objvalue) # value of objective function
+##   list(optpar = optRes$optpar,
+##        objvalue = optRes$objvalue)
 ## }
 
 
 ###################################################
-### code chunk number 24: vignette_mvord.Rnw:1094-1101
+### code chunk number 28: vignette_mvord.Rnw:1127-1134
 ###################################################
-start.values = list(theta = list(c(-3,-1,0,0.5,2.5),
-                                 c(-3,-1,0,0.5,2,3.5),
+start.values = list(theta = list(c(-3, -1, 0, 0.5, 2.5),
+                                 c(-3, -1, 0, 0.5, 2, 3.5),
                                  c(0)),
-                    beta = list(c(0.05,-0.05,-0.8,1,0.2),
-                                c(-0.5,0.2),
-                                c(-0.3,0.3),
-                                c(0.5,-1.1,0.7,0.3,-1.2)))
+                    beta = list(c(0.05, -0.05, -0.8, 1, 0.2),
+                                c(-0.5, 0.2),
+                                c(-0.3, 0.3),
+                                c(0.5, -1.1, 0.7, 0.3, -1.2)))
 
 
 ###################################################
-### code chunk number 25: vignette_mvord.Rnw:1145-1158 (eval = FALSE)
+### code chunk number 29: vignette_mvord.Rnw:1190-1204 (eval = FALSE)
 ###################################################
-## multord2(formula,
-##          error.structure = corGeneral(~1),
-##          data,
-##          link = c("probit", "logit"),
-##          coef.constraints = NULL,
-##          coef.values = NULL,
-##          threshold.constraints = NULL,
-##          threshold.values = NULL,
-##          weights = NULL,
-##          se = TRUE,
-##          start.values = NULL,
-##          solver = "BFGS",
-##          control = list(maxit = 200000, trace = 1, kkt = FALSE))
+## mvord2(formula,
+##        data,
+##        error.structure = corGeneral(~ 1),
+##        link = mvprobit(),
+##        coef.constraints = NULL,
+##        coef.values = NULL,
+##        threshold.constraints = NULL,
+##        threshold.values = NULL,
+##        weights = NULL,
+##        se = TRUE,
+##        start.values = NULL,
+##        solver = "BFGS",
+##        PL.lag = NULL,
+##        control = list(maxit = 200000, trace = 1, kkt = FALSE))
 
 
 ###################################################
-### code chunk number 26: vignette_mvord.Rnw:1172-1173
+### code chunk number 30: vignette_mvord.Rnw:1212-1213
 ###################################################
-head(data_cr_multord2, n = 3)
+formula <- cbind(Y1, ..., Yq) ~ 0 + X1 + ... + Xp
 
 
 ###################################################
-### code chunk number 27: vignette_mvord.Rnw:1177-1178
+### code chunk number 31: vignette_mvord.Rnw:1423-1425
 ###################################################
-formula <- cbind(R1, R2, R3) ~ 0 + X1 + ... + Xp
+head(data_cr_mvord, n = 3)
+str(data_cr_mvord, vec.len = 3)
 
 
 ###################################################
-### code chunk number 28: vignette_mvord.Rnw:1215-1217
+### code chunk number 32: vignette_mvord.Rnw:1428-1430
 ###################################################
-head(data_cr_multord, n = 3)
-str(data_cr_multord, vec.len = 3)
-
-
-###################################################
-### code chunk number 29: vignette_mvord.Rnw:1220-1222
-###################################################
-nfirms <- length(unique(data_cr_multord$firm_id))
-table(data_cr_multord$rater_id)/nfirms
-
-
-###################################################
-### code chunk number 30: vignette_mvord.Rnw:1224-1225
-###################################################
-tab <- round(table(data_cr_multord$rater_id)/nfirms * 100)
-
-
-###################################################
-### code chunk number 31: vignette_mvord.Rnw:1231-1233
-###################################################
-by(data_cr_multord,  data_cr_multord$rater_id,
+by(data_cr_mvord,  data_cr_mvord$rater_id,
     function(x) table(x$rating))
 
 
 ###################################################
-### code chunk number 32: vignette_mvord.Rnw:1237-1239
+### code chunk number 33: vignette_mvord.Rnw:1433-1435
 ###################################################
 formula <- rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR
 formula
 
 
 ###################################################
-### code chunk number 33: vignette_mvord.Rnw:1242-1244
+### code chunk number 34: vignette_mvord.Rnw:1438-1440
 ###################################################
 index <- c("firm_id", "rater_id")
 index
 
 
 ###################################################
-### code chunk number 34: vignette_mvord.Rnw:1247-1249
+### code chunk number 35: vignette_mvord.Rnw:1443-1445
 ###################################################
 response.names <- c("R1", "R2", "R3", "R4")
 response.names
 
 
 ###################################################
-### code chunk number 35: vignette_mvord.Rnw:1252-1258
+### code chunk number 36: vignette_mvord.Rnw:1448-1454
 ###################################################
 response.levels <-  list(rev(LETTERS[1:6]),
                          rev(LETTERS[1:6]),
@@ -303,23 +305,23 @@ response.levels
 
 
 ###################################################
-### code chunk number 36: vignette_mvord.Rnw:1266-1269
+### code chunk number 37: vignette_mvord.Rnw:1462-1465
 ###################################################
- threshold.constraints <- c(1,1,2,3)
+ threshold.constraints <- c(1, 1, 2, 3)
  names(threshold.constraints) <- response.names
  threshold.constraints
 
 
 ###################################################
-### code chunk number 37: vignette_mvord.Rnw:1272-1283
+### code chunk number 38: vignette_mvord.Rnw:1468-1479
 ###################################################
-coef.constraints = cbind(c(1,NA,1,NA),
-                         c(NA,NA,NA,1),
-                         c(1,1,1,NA),
-                         c(1,2,3,4),
-                         c(1,1,1,4),
-                         c(1,2,3,4),
-                         c(NA,NA,NA,1))
+coef.constraints <- cbind(c(1, NA, 1, NA),
+                          c(NA, NA, NA, 1),
+                          c(1, 1, 1, NA),
+                          c(1, 2, 3, 4),
+                          c(1, 1, 1, 4),
+                          c(1, 2, 3, 4),
+                          c(NA, NA, NA, 1))
 rownames(coef.constraints) <- response.names
 colnames(coef.constraints) <- c("ICR", "LR", "LEV1", "LEV2",
                            "PR", "lRSIZE", "lSYSR")
@@ -327,14 +329,14 @@ coef.constraints
 
 
 ###################################################
-### code chunk number 38: vignette_mvord.Rnw:1286-1297
+### code chunk number 39: vignette_mvord.Rnw:1482-1493
 ###################################################
 coef.values <- cbind(c(NA, 0, NA, 0),
                      c(0, 0, 0, NA),
-                     c(NA, NA, NA, NA),
                      c(NA, NA, NA, 0),
                      c(NA, NA, NA, NA),
                      c(NA, NA, NA, NA),
+                     c(NA, NA, NA, NA),
                      c(0, 0, 0, NA))
 rownames(coef.values) <- response.names
 colnames(coef.values) <- c("ICR", "LR", "LEV1", "LEV2",
@@ -343,78 +345,80 @@ coef.values
 
 
 ###################################################
-### code chunk number 39: vignette_mvord.Rnw:1310-1311
+### code chunk number 40: vignette_mvord.Rnw:1505-1506
 ###################################################
-link <- "logit"
+link <- mvlogit()
 
 
 ###################################################
-### code chunk number 40: vignette_mvord.Rnw:1314-1316
+### code chunk number 41: vignette_mvord.Rnw:1509-1511
 ###################################################
 error.structure <- corGeneral(~ 1)
 error.structure
 
 
 ###################################################
-### code chunk number 41: vignette_mvord.Rnw:1333-1337
+### code chunk number 42: vignette_mvord.Rnw:1514-1518
 ###################################################
-covar_names <- c("ICR", "LR","LEV1","LEV2", "PR","lRSIZE","lSYSR")
-data_cr_multord_scaled <- do.call("rbind.data.frame",
-  by(data_cr_multord, data_cr_multord$rater_id,
-    function(x){x[, covar_names] <- scale(x[, covar_names]); x}))
+covar_names <- c("ICR", "LR", "LEV1", "LEV2", "PR", "lRSIZE", "lSYSR")
+ data_cr_mvord_scaled <- do.call("rbind.data.frame",
+   by(data_cr_mvord, data_cr_mvord$rater_id,
+     function(x){x[, covar_names] <- scale(x[, covar_names]); x}))
 
 
 ###################################################
-### code chunk number 42: vignette_mvord.Rnw:1342-1361 (eval = FALSE)
+### code chunk number 43: vignette_mvord.Rnw:1521-1541 (eval = FALSE)
 ###################################################
-## res_cor_logit <- multord(
+## res_cor_logit <- mvord(
 ##   formula = rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR,
+##   data = data_cr_mvord_scaled,
 ##   error.structure = corGeneral(~ 1),
-##   link = "logit",
-##   data = data_cr_multord_scaled,
+##   link = mvlogit(),
 ##   index = c("firm_id", "rater_id"),
 ##   response.names = c("R1", "R2", "R3", "R4"),
 ##   response.levels = list(rev(LETTERS[1:6]),
 ##                          rev(LETTERS[1:6]),
 ##                          rev(LETTERS[7:13]),
 ##                          rev(LETTERS[14:15])),
-##   coef.constraints = cbind(c(1,NA,1,NA),
-##                            c(NA,NA,NA,1),
-##                            c(1,1,1,NA),
-##                            c(1,2,3,4),
-##                            c(1,1,1,4),
-##                            c(1,2,3,4),
-##                            c(NA,NA,NA,1)),
-##   threshold.constraints = c(1,1,2,3))
+##   coef.constraints = cbind(c(1, NA, 1, NA),
+##                            c(NA, NA, NA, 1),
+##                            c(1, 1, 1, NA),
+##                            c(1, 2, 3, 4),
+##                            c(1, 1, 1, 4),
+##                            c(1, 2, 3, 4),
+##                            c(NA, NA, NA, 1)),
+##   threshold.constraints = c(1, 1, 2, 3),
+##   solver = "newuoa")
 
 
 ###################################################
-### code chunk number 43: vignette_mvord.Rnw:1364-1394
+### code chunk number 44: vignette_mvord.Rnw:1544-1575
 ###################################################
 FILE <- "res_cor_logit.rda"
 if (cache & file.exists(FILE)) {
   load(FILE)
 } else {
   if (cache) {
-    res_cor_logit <- multord(
+    res_cor_logit <- mvord(
       formula = rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR,
       error.structure = corGeneral(~ 1),
-      link = "logit",
-      data = data_cr_multord_scaled,
+      link = mvlogit(),
+      data = data_cr_mvord_scaled,
       index = c("firm_id", "rater_id"),
       response.names = c("R1", "R2", "R3", "R4"),
       response.levels = list(rev(LETTERS[1:6]),
                          rev(LETTERS[1:6]),
                          rev(LETTERS[7:13]),
                          rev(LETTERS[14:15])),
-      coef.constraints = cbind(c(1,NA,1,NA),
-                               c(NA,NA,NA,1),
-                               c(1,1,1,NA),
-                               c(1,2,3,4),
-                               c(1,1,1,4),
-                               c(1,2,3,4),
-                               c(NA,NA,NA,1)),
-      threshold.constraints = c(1,1,2,3))
+      coef.constraints = cbind(c(1, NA, 1, NA),
+                               c(NA, NA, NA, 1),
+                               c(1, 1, 1, NA),
+                               c(1, 2, 3, 4),
+                               c(1, 1, 1, 4),
+                               c(1, 2, 3, 4),
+                               c(NA, NA, NA, 1)),
+      threshold.constraints = c(1, 1, 2, 3),
+      solver = "newuoa")
   save(res_cor_logit, file  = FILE)
   } else {
       if(file.exists(FILE)) file.remove(FILE)
@@ -424,121 +428,121 @@ if (cache & file.exists(FILE)) {
 
 
 ###################################################
-### code chunk number 44: vignette_mvord.Rnw:1399-1400
+### code chunk number 45: vignette_mvord.Rnw:1579-1580
 ###################################################
 summary(res_cor_logit, call = FALSE)
 
 
 ###################################################
-### code chunk number 45: vignette_mvord.Rnw:1403-1404
+### code chunk number 46: vignette_mvord.Rnw:1583-1584
 ###################################################
 print(res_cor_logit, call = FALSE)
 
 
 ###################################################
-### code chunk number 46: vignette_mvord.Rnw:1407-1408
+### code chunk number 47: vignette_mvord.Rnw:1587-1588 (eval = FALSE)
 ###################################################
-summary(res_cor_logit, short = FALSE, call = FALSE)
+## summary(res_cor_logit, short = FALSE, call = FALSE)
 
 
 ###################################################
-### code chunk number 47: vignette_mvord.Rnw:1411-1412
+### code chunk number 48: vignette_mvord.Rnw:1591-1592
 ###################################################
 thresholds(res_cor_logit)
 
 
 ###################################################
-### code chunk number 48: vignette_mvord.Rnw:1415-1416
+### code chunk number 49: vignette_mvord.Rnw:1595-1596
 ###################################################
 coef(res_cor_logit)
 
 
 ###################################################
-### code chunk number 49: vignette_mvord.Rnw:1419-1420
+### code chunk number 50: vignette_mvord.Rnw:1599-1600
 ###################################################
 get.error.struct(res_cor_logit)
 
 
 ###################################################
-### code chunk number 50: vignette_mvord.Rnw:1431-1433
+### code chunk number 51: vignette_mvord.Rnw:1610-1612
 ###################################################
-head(data_cr_multord2, n = 3)
-str(data_cr_multord2, vec.len = 2)
+head(data_cr_mvord2, n = 3)
+str(data_cr_mvord2, vec.len = 2)
 
 
 ###################################################
-### code chunk number 51: vignette_mvord.Rnw:1437-1438
+### code chunk number 52: vignette_mvord.Rnw:1615-1616
 ###################################################
-data_cr_multord2[, covar_names] <- scale(data_cr_multord2[, covar_names])
+data_cr_mvord2[, covar_names] <- scale(data_cr_mvord2[, covar_names])
 
 
 ###################################################
-### code chunk number 52: vignette_mvord.Rnw:1441-1455 (eval = FALSE)
+### code chunk number 53: vignette_mvord.Rnw:1619-1633 (eval = FALSE)
 ###################################################
-## res_cor_logit <- multord(
+## res_cor_logit <- mvord2(
 ##   formula = cbind(R1, R2, R3, R4) ~ 0 + ICR + LR + LEV1 + LEV2 + PR +
 ##                                         lRSIZE + lSYSR,
 ##   error.structure = corGeneral(~ 1),
-##   link = "logit",
-##   data = data_cr_multord_scaled,
-##   coef.constraints = cbind(c(1,NA,1,NA),
-##                            c(NA,NA,NA,1),
-##                            c(1,1,1,NA),
-##                            c(1,2,3,4),
-##                            c(1,1,1,4),
-##                            c(1,2,3,4),
-##                            c(NA,NA,NA,1)),
-##   threshold.constraints = c(1,1,2,3))
+##   link = mvlogit(),
+##   data = data_cr_mvord_scaled,
+##   coef.constraints = cbind(c(1, NA, 1, NA),
+##                            c(NA, NA, NA, 1),
+##                            c(1, 1, 1, NA),
+##                            c(1, 2, 3, 4),
+##                            c(1, 1, 1, 4),
+##                            c(1, 2, 3, 4),
+##                            c(NA, NA, NA, 1)),
+##   threshold.constraints = c(1, 1, 2, 3))
 
 
 ###################################################
-### code chunk number 53: vignette_mvord.Rnw:1462-1464
+### code chunk number 54: vignette_mvord.Rnw:1640-1642
 ###################################################
 str(data_cr_panel, vec.len = 3)
 head(data_cr_panel, n = 3)
 
 
 ###################################################
-### code chunk number 54: vignette_mvord.Rnw:1467-1468
+### code chunk number 55: vignette_mvord.Rnw:1645-1646
 ###################################################
 summary(rowSums(with(data_cr_panel, table(firm_id, year))))
 
 
 ###################################################
-### code chunk number 55: vignette_mvord.Rnw:1471-1472
+### code chunk number 56: vignette_mvord.Rnw:1649-1650
 ###################################################
 with(data_cr_panel, table(year))
 
 
 ###################################################
-### code chunk number 56: vignette_mvord.Rnw:1476-1478
+### code chunk number 57: vignette_mvord.Rnw:1654-1656
 ###################################################
 formula <- rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR
 formula
 
 
 ###################################################
-### code chunk number 57: vignette_mvord.Rnw:1482-1484
+### code chunk number 58: vignette_mvord.Rnw:1659-1661
 ###################################################
 index <- c("firm_id", "year")
 index
 
 
 ###################################################
-### code chunk number 58: vignette_mvord.Rnw:1489-1491
+### code chunk number 59: vignette_mvord.Rnw:1665-1667
 ###################################################
 response.names <- paste0("year", 3:10)
 response.names
 
 
 ###################################################
-### code chunk number 59: vignette_mvord.Rnw:1495-1496
+### code chunk number 60: vignette_mvord.Rnw:1670-1671
 ###################################################
 levels(data_cr_panel$rating)
 
 
 ###################################################
-### code chunk number 60: vignette_mvord.Rnw:1499-1503
+### code chunk number 61: vignette_mvord.Rnw:1674-1678
 ###################################################
 response.levels <- rep(list(levels(data_cr_panel$rating)),
                        length(response.names))
@@ -547,7 +551,7 @@ response.levels
 
 
 ###################################################
-### code chunk number 61: vignette_mvord.Rnw:1509-1512
+### code chunk number 62: vignette_mvord.Rnw:1683-1686
 ###################################################
 threshold.constraints <- rep(1, length(response.names))
 names(threshold.constraints) <- response.names
@@ -555,22 +559,22 @@ threshold.constraints
 
 
 ###################################################
-### code chunk number 62: vignette_mvord.Rnw:1517-1520
+### code chunk number 63: vignette_mvord.Rnw:1691-1694
 ###################################################
-coef.constraints = c(rep(1, 3),  rep(2, 5))
+coef.constraints <- c(rep(1, 3),  rep(2, 5))
 names(coef.constraints) <- response.names
 coef.constraints
 
 
 ###################################################
-### code chunk number 63: vignette_mvord.Rnw:1523-1525
+### code chunk number 64: vignette_mvord.Rnw:1697-1699
 ###################################################
-error.structure = corAR1(~ BSEC)
+error.structure <- corAR1(~ BSEC)
 error.structure
 
 
 ###################################################
-### code chunk number 64: vignette_mvord.Rnw:1531-1534
+### code chunk number 65: vignette_mvord.Rnw:1703-1706
 ###################################################
 data_cr_panel_scaled <- do.call("rbind.data.frame",
   by(data_cr_panel, data_cr_panel$year,
@@ -578,15 +582,15 @@ data_cr_panel_scaled <- do.call("rbind.data.frame",
 
 
 ###################################################
-### code chunk number 65: vignette_mvord.Rnw:1536-1547 (eval = FALSE)
+### code chunk number 66: vignette_mvord.Rnw:1709-1720 (eval = FALSE)
 ###################################################
-## res_AR1_probit <- multord(
+## res_AR1_probit <- mvord(
 ##     formula = rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR,
 ##     index = c("firm_id", "year"),
 ##     data = data_cr_panel_scaled,
 ##     response.levels = rep(list(levels(data_cr_panel$rating)), 8),
 ##     response.names = paste0("year", 3:10),
-##     link = "probit",
+##     link = mvprobit(),
 ##     error.structure = corAR1(~ BSEC),
 ##     coef.constraints = c(rep(1, 3),  rep(2, 5)),
 ##     threshold.constraints = rep(1, 8),
@@ -594,17 +598,17 @@ data_cr_panel_scaled <- do.call("rbind.data.frame",
 
 
 ###################################################
-### code chunk number 66: vignette_mvord.Rnw:1549-1570
+### code chunk number 67: vignette_mvord.Rnw:1722-1743
 ###################################################
 FILE <- "res_AR1_probit.rda"
 if (cache & file.exists(FILE)) {
   load(FILE)
 } else {
   if (cache) {
-    res_AR1_probit <- multord(
+    res_AR1_probit <- mvord(
       formula = rating ~ 0 + ICR + LR + LEV1 + LEV2 + PR + lRSIZE + lSYSR,
       error.structure = corAR1(~ BSEC),
-      link = "probit",
+      link = mvprobit(),
       data = data_cr_panel_scaled,
       index = c("firm_id", "year"),
       response.names = paste0("year", 3:10),
@@ -620,49 +624,49 @@ if (cache & file.exists(FILE)) {
 
 
 ###################################################
-### code chunk number 67: vignette_mvord.Rnw:1575-1576
+### code chunk number 68: vignette_mvord.Rnw:1747-1748
 ###################################################
 summary(res_AR1_probit, short = TRUE, call = FALSE, digits = 6)
 
 
 ###################################################
-### code chunk number 68: vignette_mvord.Rnw:1579-1580
+### code chunk number 69: vignette_mvord.Rnw:1751-1752
 ###################################################
 print(res_AR1_probit, call = FALSE, digits = 4)
 
 
 ###################################################
-### code chunk number 69: vignette_mvord.Rnw:1583-1584 (eval = FALSE)
+### code chunk number 70: vignette_mvord.Rnw:1755-1756 (eval = FALSE)
 ###################################################
 ## summary(res_AR1_probit, short = FALSE, call = FALSE)
 
 
 ###################################################
-### code chunk number 70: vignette_mvord.Rnw:1587-1588
+### code chunk number 71: vignette_mvord.Rnw:1759-1760
 ###################################################
 thresholds(res_AR1_probit)
 
 
 ###################################################
-### code chunk number 71: vignette_mvord.Rnw:1591-1592
+### code chunk number 72: vignette_mvord.Rnw:1763-1764
 ###################################################
 coef(res_AR1_probit)
 
 
 ###################################################
-### code chunk number 72: vignette_mvord.Rnw:1595-1596
+### code chunk number 73: vignette_mvord.Rnw:1767-1768
 ###################################################
 get.error.struct(res_AR1_probit)
 
 
 ###################################################
-### code chunk number 73: vignette_mvord.Rnw:1599-1600
+### code chunk number 74: vignette_mvord.Rnw:1771-1772
 ###################################################
 head(get.error.struct(res_AR1_probit, type = "corr"), n = 3)
 
 
 ###################################################
-### code chunk number 74: vignette_mvord.Rnw:1604-1605
+### code chunk number 75: vignette_mvord.Rnw:1775-1776
 ###################################################
 head(get.error.struct(res_AR1_probit, type = "sigmas"), n = 1)
 
